<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// E
	'explication_url_statique_ressources' => 'Un URL che consente di offrire file statici (immagini, JS, ecc...) senza cookie. Di solito un sottodominio alternativo che punta anche al sito.',

	// I
	'info_compresseur_titre' => 'Ottimizzazione e compressione',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Scripts',
	'item_compresseur_css' => 'Attiva la compressione dei foglio di stile (CSS)',
	'item_compresseur_js' => 'Attivare la compressione degli script (javascript)',

	// L
	'label_url_statique_ressources' => 'URL delle risorse',

	// T
	'texte_compacter_avertissement' => 'Fare attenzione a non attivare queste opzioni durante la fase di sviluppo del sito: gli elementi compressi sono completamente illeggibili.',
	'texte_compacter_script_css' => 'SPIP può comprimere gli script javascript e i fogli di stile CSS, per registrarli nei file statici; ciò accelera la visualizzazione del sito.',
	'titre_compacter_script_css' => 'Compressione degli script e dei CSS',
];
